@@ -15,9 +15,9 @@
 
 import datetime
 import json
+from unittest import mock
 
 import ddt
-import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import six
@@ -52,8 +52,8 @@ class MessagesBaseTest(base.V2Base):
 
         with mock.patch.object(self.protocol, 'sendMessage') as msg_mock:
             self.protocol.onMessage(req, False)
-            resp = json.loads(msg_mock.call_args[0][0])
-            self.assertEqual(201, resp['headers']['status'])
+            resp = json.loads(msg_mock.call_args[0][0].decode())
+            self.assertIn(resp['headers']['status'], [201, 204])
 
     def tearDown(self):
         super(MessagesBaseTest, self).tearDown()
@@ -67,7 +67,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
     def _test_post(self, sample_messages, in_binary=False):
@@ -82,8 +82,10 @@ class MessagesBaseTest(base.V2Base):
         req = create_req(consts.MESSAGE_POST, body, self.headers)
 
         self.protocol.onMessage(req, in_binary)
-
-        resp = loads(send_mock.call_args[0][0])
+        arg = send_mock.call_args[0][0]
+        if not in_binary:
+            arg = arg.decode()
+        resp = loads(arg)
         self.assertEqual(201, resp['headers']['status'])
         self.msg_ids = resp['body']['message_ids']
         self.assertEqual(len(sample_messages), len(self.msg_ids))
@@ -107,16 +109,20 @@ class MessagesBaseTest(base.V2Base):
                 req = create_req(action, body, headers)
 
                 self.protocol.onMessage(req, in_binary)
-
-                resp = loads(send_mock.call_args[0][0])
+                arg = send_mock.call_args[0][0]
+                if not in_binary:
+                    arg = arg.decode()
+                resp = loads(arg)
                 self.assertEqual(404, resp['headers']['status'])
 
                 # Correct project ID
                 req = create_req(action, body, self.headers)
 
                 self.protocol.onMessage(req, in_binary)
-
-                resp = loads(send_mock.call_args[0][0])
+                arg = send_mock.call_args[0][0]
+                if not in_binary:
+                    arg = arg.decode()
+                resp = loads(arg)
                 self.assertEqual(200, resp['headers']['status'])
 
                 # Check message properties
@@ -137,8 +143,10 @@ class MessagesBaseTest(base.V2Base):
         req = create_req(action, body, self.headers)
 
         self.protocol.onMessage(req, in_binary)
-
-        resp = loads(send_mock.call_args[0][0])
+        arg = send_mock.call_args[0][0]
+        if not in_binary:
+            arg = arg.decode()
+        resp = loads(arg)
         self.assertEqual(200, resp['headers']['status'])
         expected_ttls = set(m['ttl'] for m in sample_messages)
         actual_ttls = set(m['ttl'] for m in resp['body']['messages'])
@@ -163,14 +171,14 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
 
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         # Listing restriction
         body['limit'] = 21
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         # Bulk deletion restriction
@@ -180,7 +188,7 @@ class MessagesBaseTest(base.V2Base):
                 "message_ids": del_msg_ids}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data(True, False)
@@ -215,7 +223,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(201, resp['headers']['status'])
         msg_id = resp['body']['message_ids'][0]
 
@@ -226,7 +234,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(self.default_message_ttl,
                          resp['body']['messages']['ttl'])
@@ -274,7 +282,7 @@ class MessagesBaseTest(base.V2Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
         self.assertEqual(
             'Bad request. The value of the "ttl" field must be a int.',
@@ -295,7 +303,7 @@ class MessagesBaseTest(base.V2Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
         self.assertEqual(
             'Bad request. Missing "body" field.', resp['body']['exception'])
@@ -310,7 +318,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual([], resp['body']['messages'])
 
@@ -334,7 +342,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         action = consts.MESSAGE_GET
@@ -347,7 +355,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, headers)
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data(None, '[', '[]', '{}', '.')
@@ -365,7 +373,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data(-1, 59, 1209601)
@@ -381,7 +389,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     def test_exceeded_message_posting(self):
@@ -400,7 +408,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data('{"overflow": 9223372036854775808}',
@@ -419,7 +427,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     def test_delete(self):
@@ -437,7 +445,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
 
         # Delete queue
@@ -446,7 +454,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Get non existent queue
@@ -454,7 +462,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
 
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404, resp['headers']['status'])
 
         # Safe to delete non-existing ones
@@ -462,7 +470,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
 
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
     def test_bulk_delete(self):
@@ -480,7 +488,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         action = consts.MESSAGE_GET
@@ -488,7 +496,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         # Safe to delete non-existing ones
@@ -497,7 +505,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Even after the queue is gone
@@ -506,7 +514,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         action = consts.MESSAGE_DELETE_MANY
@@ -515,7 +523,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
     def test_pop_delete(self):
@@ -531,7 +539,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(2, len(resp['body']['messages']))
         self.assertEqual(239, resp['body']['messages'][0]['body'])
@@ -548,7 +556,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
 
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404, resp['headers']['status'])
 
     def test_get_multiple_invalid_messages_404s(self):
@@ -562,7 +570,7 @@ class MessagesBaseTest(base.V2Base):
         req = test_utils.create_request(action, body, self.headers)
 
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
 
     def test_delete_multiple_invalid_messages_204s(self):
@@ -577,7 +585,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     def _post_messages(self, queue_name, repeat=1):
@@ -594,7 +602,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage(req, False)
 
-        return json.loads(send_mock.call_args[0][0])
+        return json.loads(send_mock.call_args[0][0].decode())
 
     def test_invalid_request(self):
         send_mock = mock.Mock()
@@ -602,7 +610,7 @@ class MessagesBaseTest(base.V2Base):
 
         self.protocol.onMessage('foo', False)
         self.assertEqual(1, send_mock.call_count)
-        response = json.loads(send_mock.call_args[0][0])
+        response = json.loads(send_mock.call_args[0][0].decode())
         self.assertIn('error', response['body'])
         self.assertEqual({'status': 400}, response['headers'])
         self.assertEqual(
