@@ -14,13 +14,13 @@
 # limitations under the License.
 
 import datetime
+from unittest import mock
+import uuid
 
 import ddt
 import falcon
-import mock
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-from oslo_utils import uuidutils
 import six
 from testtools import matchers
 
@@ -30,7 +30,8 @@ from zaqar.transport import validation
 
 
 @ddt.ddt
-class TestMessagesMongoDB(base.V2Base):
+class TestMessagesMongoDB(base.V1_1Base):
+
     config_file = 'wsgi_mongodb.conf'
 
     @testing.requires_mongodb
@@ -40,40 +41,30 @@ class TestMessagesMongoDB(base.V2Base):
         self.default_message_ttl = self.boot.transport._defaults.message_ttl
 
         if self.conf.pooling:
-            uri = self.mongodb_url
             for i in range(4):
-                db_name = "zaqar_test_pools_" + str(i)
-                # NOTE(dynarro): we need to create a unique uri.
-                new_uri = "%s/%s" % (uri, db_name)
-                options = {'database': db_name}
-                doc = {'weight': 100, 'uri': new_uri, 'options': options}
+                uri = "%s/%s" % (self.mongodb_url, str(i))
+                doc = {'weight': 100, 'uri': uri}
                 self.simulate_put(self.url_prefix + '/pools/' + str(i),
                                   body=jsonutils.dumps(doc))
                 self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
         self.project_id = '7e55e1a7e'
-        self.headers.update({
-            'Client-ID': uuidutils.generate_uuid(),
+        self.headers = {
+            'Client-ID': str(uuid.uuid4()),
             'X-Project-ID': self.project_id
-        })
+        }
 
         # TODO(kgriffs): Add support in self.simulate_* for a "base path"
         # so that we don't have to concatenate against self.url_prefix
         # all over the place.
         self.queue_path = self.url_prefix + '/queues/fizbit'
-        self.encrypted_queue_path = self.url_prefix + '/queues/secretbit'
         self.messages_path = self.queue_path + '/messages'
-        self.encrypted_messages_path = self.encrypted_queue_path + '/messages'
 
         doc = '{"_ttl": 60}'
         self.simulate_put(self.queue_path, body=doc, headers=self.headers)
-        doc = '{"_ttl": 60, "_enable_encrypt_messages": true}'
-        self.simulate_put(self.encrypted_queue_path, body=doc,
-                          headers=self.headers)
 
     def tearDown(self):
         self.simulate_delete(self.queue_path, headers=self.headers)
-        self.simulate_delete(self.encrypted_queue_path, headers=self.headers)
         if self.conf.pooling:
             for i in range(4):
                 self.simulate_delete(self.url_prefix + '/pools/' + str(i),
@@ -100,15 +91,10 @@ class TestMessagesMongoDB(base.V2Base):
                            body=sample_doc, headers=self.headers)
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
-    def _test_post(self, sample_messages, is_encrypted=False):
+    def _test_post(self, sample_messages):
         sample_doc = jsonutils.dumps({'messages': sample_messages})
-        messages_path = None
-        if is_encrypted:
-            messages_path = self.encrypted_messages_path
-        else:
-            messages_path = self.messages_path
 
-        result = self.simulate_post(messages_path,
+        result = self.simulate_post(self.messages_path,
                                     body=sample_doc, headers=self.headers)
         self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
@@ -136,7 +122,7 @@ class TestMessagesMongoDB(base.V2Base):
         with mock.patch(timeutils_utcnow) as mock_utcnow:
             mock_utcnow.return_value = now
             for msg_id in msg_ids:
-                message_uri = messages_path + '/' + msg_id
+                message_uri = self.messages_path + '/' + msg_id
 
                 headers = self.headers.copy()
                 headers['X-Project-ID'] = '777777'
@@ -161,7 +147,7 @@ class TestMessagesMongoDB(base.V2Base):
 
         # Test bulk GET
         query_string = 'ids=' + ','.join(msg_ids)
-        result = self.simulate_get(messages_path,
+        result = self.simulate_get(self.messages_path,
                                    query_string=query_string,
                                    headers=self.headers)
 
@@ -215,22 +201,6 @@ class TestMessagesMongoDB(base.V2Base):
 
         self._test_post(sample_messages)
 
-    def test_post_single_encrypted(self):
-        sample_messages = [
-            {'body': {'key': 'value'}, 'ttl': 200},
-        ]
-
-        self._test_post(sample_messages)
-
-    def test_post_multiple_encrypted(self):
-        sample_messages = [
-            {'body': 239, 'ttl': 100},
-            {'body': {'key': 'value'}, 'ttl': 200},
-            {'body': [1, 3], 'ttl': 300},
-        ]
-
-        self._test_post(sample_messages)
-
     def test_post_optional_ttl(self):
         sample_messages = {
             'messages': [
@@ -292,63 +262,6 @@ class TestMessagesMongoDB(base.V2Base):
         self._post_messages(self.url_prefix + '/queues/nonexistent/messages')
         self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
-    def test_post_using_queue_default_message_ttl(self):
-        queue_path = self.url_prefix + '/queues/test_queue1'
-        messages_path = queue_path + '/messages'
-        doc = '{"_default_message_ttl": 999}'
-        self.simulate_put(queue_path, body=doc, headers=self.headers)
-        self.addCleanup(self.simulate_delete, queue_path, headers=self.headers)
-        sample_messages = {
-            'messages': [
-                {'body': {'key': 'value'}},
-            ],
-        }
-
-        sample_doc = jsonutils.dumps(sample_messages)
-        result = self.simulate_post(messages_path,
-                                    body=sample_doc, headers=self.headers)
-        result_doc = jsonutils.loads(result[0])
-        href = result_doc['resources'][0]
-        result = self.simulate_get(href, headers=self.headers)
-        message = jsonutils.loads(result[0])
-
-        self.assertEqual(999, message['ttl'])
-
-    def test_post_using_queue_max_messages_post_size(self):
-        queue_path = self.url_prefix + '/queues/test_queue2'
-        messages_path = queue_path + '/messages'
-        doc = '{"_max_messages_post_size": 1023}'
-        self.simulate_put(queue_path, body=doc, headers=self.headers)
-        self.addCleanup(self.simulate_delete, queue_path, headers=self.headers)
-        sample_messages = {
-            'messages': [
-                {'body': {'key': 'a' * 1204}},
-            ],
-        }
-
-        sample_doc = jsonutils.dumps(sample_messages)
-        self.simulate_post(messages_path,
-                           body=sample_doc, headers=self.headers)
-        self.assertEqual(falcon.HTTP_400, self.srmock.status)
-
-    def test_post_using_queue_max_messages_post_size_with_encrypted(self):
-        queue_path = self.url_prefix + '/queues/test_queue2'
-        messages_path = queue_path + '/messages'
-        doc = ('{"_max_messages_post_size": 1023, '
-               '"_enable_encrypt_messages": true}')
-        self.simulate_put(queue_path, body=doc, headers=self.headers)
-        self.addCleanup(self.simulate_delete, queue_path, headers=self.headers)
-        sample_messages = {
-            'messages': [
-                {'body': {'key': 'a' * 1204}},
-            ],
-        }
-
-        sample_doc = jsonutils.dumps(sample_messages)
-        self.simulate_post(messages_path,
-                           body=sample_doc, headers=self.headers)
-        self.assertEqual(falcon.HTTP_400, self.srmock.status)
-
     def test_get_from_missing_queue(self):
         body = self.simulate_get(self.url_prefix +
                                  '/queues/nonexistent/messages',
@@ -370,7 +283,7 @@ class TestMessagesMongoDB(base.V2Base):
 
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
-    @ddt.data(None, '[', '[]', '{}', '.', '123')
+    @ddt.data(None, '[', '[]', '{}', '.')
     def test_post_bad_message(self, document):
         self.simulate_post(self.queue_path + '/messages',
                            body=document,
@@ -429,24 +342,6 @@ class TestMessagesMongoDB(base.V2Base):
         self.simulate_delete(target, headers=self.headers)
         self.assertEqual(falcon.HTTP_204, self.srmock.status)
 
-    def test_delete_with_encrypted(self):
-        self._post_messages(self.encrypted_messages_path)
-        msg_id = self._get_msg_id(self.srmock.headers_dict)
-        target = self.encrypted_messages_path + '/' + msg_id
-
-        self.simulate_get(target, headers=self.headers)
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
-
-        self.simulate_delete(target, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-        self.simulate_get(target, headers=self.headers)
-        self.assertEqual(falcon.HTTP_404, self.srmock.status)
-
-        # Safe to delete non-existing ones
-        self.simulate_delete(target, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
     def test_bulk_delete(self):
         path = self.queue_path + '/messages'
         self._post_messages(path, repeat=5)
@@ -473,62 +368,6 @@ class TestMessagesMongoDB(base.V2Base):
         self.simulate_delete(target, query_string=params, headers=self.headers)
         self.assertEqual(falcon.HTTP_204, self.srmock.status)
 
-    def test_bulk_delete_with_encrpted(self):
-        path = self.encrypted_queue_path + '/messages'
-        self._post_messages(path, repeat=5)
-        [target, params] = self.srmock.headers_dict['location'].split('?')
-
-        # Deleting the whole collection is denied
-        self.simulate_delete(path, headers=self.headers)
-        self.assertEqual(falcon.HTTP_400, self.srmock.status)
-
-        self.simulate_delete(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-        self.simulate_get(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_404, self.srmock.status)
-
-        # Safe to delete non-existing ones
-        self.simulate_delete(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-        # Even after the queue is gone
-        self.simulate_delete(self.queue_path, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-        self.simulate_delete(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-    def test_bulk_delete_with_claim_ids(self):
-        self.conf.set_override('message_delete_with_claim_id', True,
-                               'transport')
-        path = self.queue_path
-        self._post_messages(path + '/messages', repeat=5)
-        [target, params] = self.srmock.headers_dict['location'].split('?')
-
-        body = self.simulate_post(path + '/claims',
-                                  body='{"ttl": 100, "grace": 100}',
-                                  headers=self.headers)
-        self.assertEqual(falcon.HTTP_201, self.srmock.status)
-        claimed = jsonutils.loads(body[0])['messages']
-        claime_ids = '&claim_ids='
-        for claim in claimed:
-            claime_ids += claim['href'].split('claim_id=')[1] + ','
-
-        params = params + claime_ids
-        self.simulate_delete(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_204, self.srmock.status)
-
-    def test_bulk_delete_without_claim_ids(self):
-        self.conf.set_override('message_delete_with_claim_id', True,
-                               'transport')
-        path = self.queue_path
-        self._post_messages(path + '/messages', repeat=5)
-        [target, params] = self.srmock.headers_dict['location'].split('?')
-
-        self.simulate_delete(target, query_string=params, headers=self.headers)
-        self.assertEqual(falcon.HTTP_400, self.srmock.status)
-
     def test_list(self):
         path = self.queue_path + '/messages'
         self._post_messages(path, repeat=10)
@@ -579,35 +418,6 @@ class TestMessagesMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
         self._empty_message_list(body)
 
-    def test_list_with_encrpyted(self):
-        path = self.encrypted_queue_path + '/messages'
-        self._post_messages(path, repeat=10)
-
-        query_string = 'limit=3&echo=true'
-        body = self.simulate_get(path,
-                                 query_string=query_string,
-                                 headers=self.headers)
-
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
-
-        cnt = 0
-        while jsonutils.loads(body[0])['messages'] != []:
-            contents = jsonutils.loads(body[0])
-            [target, params] = contents['links'][0]['href'].split('?')
-
-            for msg in contents['messages']:
-                self.simulate_get(msg['href'], headers=self.headers)
-                self.assertEqual(falcon.HTTP_200, self.srmock.status)
-
-            body = self.simulate_get(target,
-                                     query_string=params,
-                                     headers=self.headers)
-            cnt += 1
-
-        self.assertEqual(4, cnt)
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
-        self._empty_message_list(body)
-
     def test_list_with_bad_marker(self):
         path = self.queue_path + '/messages'
         self._post_messages(path, repeat=5)
@@ -805,7 +615,7 @@ class TestMessagesMongoDBPooled(TestMessagesMongoDB):
         self.skipTest("Need to implement pooled queue listing.")
 
 
-class TestMessagesFaultyDriver(base.V2BaseFaulty):
+class TestMessagesFaultyDriver(base.V1_1BaseFaulty):
     config_file = 'wsgi_faulty.conf'
 
     def test_simple(self):
@@ -813,14 +623,14 @@ class TestMessagesFaultyDriver(base.V2BaseFaulty):
         path = self.url_prefix + '/queues/fizbit/messages'
         body = '{"messages": [{"body": 239, "ttl": 100}]}'
         headers = {
-            'Client-ID': uuidutils.generate_uuid(),
+            'Client-ID': str(uuid.uuid4()),
             'X-Project-ID': project_id
         }
 
         self.simulate_post(path,
                            body=body,
                            headers=headers)
-        self.assertEqual(falcon.HTTP_500, self.srmock.status)
+        self.assertEqual(falcon.HTTP_503, self.srmock.status)
 
         self.simulate_get(path,
                           headers=headers)
