@@ -15,10 +15,10 @@
 
 import datetime
 import json
+from unittest import mock
 
 import ddt
 import falcon
-import mock
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
@@ -29,7 +29,7 @@ from zaqar.tests.unit.transport.wsgi import base
 
 
 @ddt.ddt
-class TestClaimsMongoDB(base.V1_1Base):
+class TestClaimsMongoDB(base.V2Base):
 
     config_file = 'wsgi_mongodb.conf'
 
@@ -66,6 +66,7 @@ class TestClaimsMongoDB(base.V1_1Base):
 
         for db in storage.message_databases:
             connection.drop_database(db)
+
         self.simulate_delete(self.queue_path, headers=self.headers)
 
         super(TestClaimsMongoDB, self).tearDown()
@@ -287,7 +288,7 @@ class TestClaimsMongoDB(base.V1_1Base):
         self.assertEqual(falcon.HTTP_404, self.srmock.status)
 
 
-class TestClaimsFaultyDriver(base.V1_1BaseFaulty):
+class TestClaimsFaultyDriver(base.V2BaseFaulty):
 
     config_file = 'wsgi_faulty.conf'
 
