@@ -16,12 +16,13 @@
 
 import datetime
 import re
+import uuid
 
-from oslo_config import cfg
 from oslo_utils import timeutils
 import six
 
 from zaqar.common import consts
+from zaqar.conf import transport
 from zaqar.i18n import _
 
 
@@ -31,81 +32,13 @@ MIN_CLAIM_GRACE = 60
 MIN_DELAY_TTL = 0
 MIN_SUBSCRIPTION_TTL = 60
 _PURGBLE_RESOURCE_TYPES = {'messages', 'subscriptions'}
-
-_TRANSPORT_LIMITS_OPTIONS = (
-    cfg.IntOpt('max_queues_per_page', default=20,
-               deprecated_name='queue_paging_uplimit',
-               deprecated_group='limits:transport',
-               help='Defines the maximum number of queues per page.'),
-
-    cfg.IntOpt('max_messages_per_page', default=20,
-               deprecated_name='message_paging_uplimit',
-               deprecated_group='limits:transport',
-               help='Defines the maximum number of messages per page.'),
-
-    cfg.IntOpt('max_subscriptions_per_page', default=20,
-               deprecated_name='subscription_paging_uplimit',
-               deprecated_group='limits:transport',
-               help='Defines the maximum number of subscriptions per page.'),
-
-    cfg.IntOpt('max_messages_per_claim_or_pop', default=20,
-               deprecated_name='max_messages_per_claim',
-               help='The maximum number of messages that can be claimed (OR) '
-                    'popped in a single request'),
-
-    cfg.IntOpt('max_queue_metadata', default=64 * 1024,
-               deprecated_name='metadata_size_uplimit',
-               deprecated_group='limits:transport',
-               help='Defines the maximum amount of metadata in a queue.'),
-
-    cfg.IntOpt('max_messages_post_size', default=256 * 1024,
-               deprecated_name='message_size_uplimit',
-               deprecated_group='limits:transport',
-               deprecated_opts=[cfg.DeprecatedOpt('max_message_size')],
-               help='Defines the maximum size of message posts.'),
-
-    cfg.IntOpt('max_message_ttl', default=1209600,
-               deprecated_name='message_ttl_max',
-               deprecated_group='limits:transport',
-               help='Maximum amount of time a message will be available.'),
-
-    cfg.IntOpt('max_message_delay', default=900,
-               help='Maximum delay seconds for messages can be claimed.'),
-
-    cfg.IntOpt('max_claim_ttl', default=43200,
-               deprecated_name='claim_ttl_max',
-               deprecated_group='limits:transport',
-               help='Maximum length of a message in claimed state.'),
-
-    cfg.IntOpt('max_claim_grace', default=43200,
-               deprecated_name='claim_grace_max',
-               deprecated_group='limits:transport',
-               help='Defines the maximum message grace period in seconds.'),
-
-    cfg.ListOpt('subscriber_types', default=['http', 'https', 'mailto',
-                                             'trust+http', 'trust+https'],
-                help='Defines supported subscriber types.'),
-
-    cfg.IntOpt('max_flavors_per_page', default=20,
-               help='Defines the maximum number of flavors per page.'),
-
-    cfg.IntOpt('max_pools_per_page', default=20,
-               help='Defines the maximum number of pools per page.'),
-)
-
-_TRANSPORT_LIMITS_GROUP = 'transport'
-
 # NOTE(kgriffs): Don't use \w because it isn't guaranteed to match
 # only ASCII characters.
-QUEUE_NAME_REGEX = re.compile('^[a-zA-Z0-9_\-.]+$')
+QUEUE_NAME_REGEX = re.compile(r'^[a-zA-Z0-9_\-.]+$')
 QUEUE_NAME_MAX_LEN = 64
 PROJECT_ID_MAX_LEN = 256
 
 
-def _config_options():
-    return [(_TRANSPORT_LIMITS_GROUP, _TRANSPORT_LIMITS_OPTIONS)]
-
-
 class ValidationFailed(ValueError):
     """User input did not follow API restrictions."""
 
@@ -117,9 +50,9 @@ class ValidationFailed(ValueError):
 class Validator(object):
     def __init__(self, conf):
         self._conf = conf
-        self._conf.register_opts(_TRANSPORT_LIMITS_OPTIONS,
-                                 group=_TRANSPORT_LIMITS_GROUP)
-        self._limits_conf = self._conf[_TRANSPORT_LIMITS_GROUP]
+        self._conf.register_opts(transport.ALL_OPTS,
+                                 group=transport.GROUP_NAME)
+        self._limits_conf = self._conf[transport.GROUP_NAME]
         self._supported_operations = ('add', 'remove', 'replace')
 
     def queue_identification(self, queue, project):
@@ -192,7 +125,7 @@ class Validator(object):
         if not pointer.startswith('/'):
             msg = _('Pointer `%s` does not start with "/".') % pointer
             raise ValidationFailed(msg)
-        if re.search('/\s*?/', pointer[1:]):
+        if re.search(r'/\s*?/', pointer[1:]):
             msg = _('Pointer `%s` contains adjacent "/".') % pointer
             raise ValidationFailed(msg)
         if len(pointer) > 1 and pointer.endswith('/'):
@@ -201,7 +134,7 @@ class Validator(object):
         if pointer[1:].strip() == '/':
             msg = _('Pointer `%s` does not contains valid token.') % pointer
             raise ValidationFailed(msg)
-        if re.search('~[^01]', pointer) or pointer.endswith('~'):
+        if re.search(r'~[^01]', pointer) or pointer.endswith('~'):
             msg = _('Pointer `%s` contains "~" not part of'
                     ' a recognized escape sequence.') % pointer
             raise ValidationFailed(msg)
@@ -408,6 +341,11 @@ class Validator(object):
                     msg, self._limits_conf.max_message_delay,
                     MIN_DELAY_TTL)
 
+        encrypted_queue = queue_metadata.get('_enable_encrypt_messages', False)
+        if encrypted_queue and not isinstance(encrypted_queue, bool):
+            msg = _(u'_enable_encrypt_messages must be boolean.')
+            raise ValidationFailed(msg)
+
         self._validate_retry_policy(queue_metadata)
 
     def queue_purging(self, document):
@@ -512,11 +450,12 @@ class Validator(object):
             raise ValidationFailed(
                 msg, self._limits_conf.max_messages_per_page)
 
-    def message_deletion(self, ids=None, pop=None):
+    def message_deletion(self, ids=None, pop=None, claim_ids=None):
         """Restrictions involving deletion of messages.
 
         :param ids: message ids passed in by the delete request
         :param pop: count of messages to be POPped
+        :param claim_ids: claim ids passed in by the delete request
         :raises ValidationFailed: if,
             pop AND id params are present together
             neither pop or id params are present
@@ -535,6 +474,13 @@ class Validator(object):
 
             raise ValidationFailed(msg)
 
+        if self._limits_conf.message_delete_with_claim_id:
+            if (ids and claim_ids is None) or (ids is None and claim_ids):
+                msg = _(u'The request should have both "ids" and "claim_ids" '
+                        'parameter in the request when '
+                        'message_delete_with_claim_id is True.')
+                raise ValidationFailed(msg)
+
         pop_uplimit = self._limits_conf.max_messages_per_claim_or_pop
         if pop is not None and not (0 < pop <= pop_uplimit):
             msg = _(u'Pop value must be at least 1 and may not '
@@ -717,3 +663,45 @@ class Validator(object):
         if limit is not None and not (0 < limit <= uplimit):
             msg = _(u'Limit must be at least 1 and no greater than {0}.')
             raise ValidationFailed(msg, self._limits_conf.max_pools_per_page)
+
+    def client_id_uuid_safe(self, client_id):
+        """Restrictions the format of client id
+
+        :param client_id: the client id of request
+        :raises ValidationFailed: if the limit is exceeded
+        """
+
+        if self._limits_conf.client_id_uuid_safe == 'off':
+            if (len(client_id) < self._limits_conf.min_length_client_id) or \
+               (len(client_id) > self._limits_conf.max_length_client_id):
+                msg = _(u'Length of client id must be at least {0} and no '
+                        'greater than {1}.')
+                raise ValidationFailed(msg,
+                                       self._limits_conf.min_length_client_id,
+                                       self._limits_conf.max_length_client_id)
+        if self._limits_conf.client_id_uuid_safe == 'strict':
+            uuid.UUID(client_id)
+
+    def topic_identification(self, topic, project):
+        """Restrictions on a project id & topic name pair.
+
+        :param queue: Name of the topic
+        :param project: Project id
+        :raises ValidationFailed: if the `name` is longer than 64
+            characters or contains anything other than ASCII digits and
+            letters, underscores, and dashes.  Also raises if `project`
+            is not None but longer than 256 characters.
+        """
+
+        if project is not None and len(project) > PROJECT_ID_MAX_LEN:
+            msg = _(u'Project ids may not be more than {0} characters long.')
+            raise ValidationFailed(msg, PROJECT_ID_MAX_LEN)
+
+        if len(topic) > QUEUE_NAME_MAX_LEN:
+            msg = _(u'Topic names may not be more than {0} characters long.')
+            raise ValidationFailed(msg, QUEUE_NAME_MAX_LEN)
+
+        if not QUEUE_NAME_REGEX.match(topic):
+            raise ValidationFailed(
+                _(u'Topic names may only contain ASCII letters, digits, '
+                  'underscores, and dashes.'))
